# pybravia

<img src="https://img.shields.io/pypi/v/pybravia" alt="PyPI Version"> <img src="https://img.shields.io/github/workflow/status/Drafteed/pybravia/CI" alt="GitHub Workflow Status"> <img src="https://img.shields.io/badge/code%20style-black-black" alt="Code style">

Python 3 async library for remote control of Sony Bravia TVs 2013 and newer.

For more information on the API used in this library, refer to [BRAVIA Professional Display Knowledge Center](https://pro-bravia.sony.net/develop/index.html).
